/*
 	File:		ADSPSecure.h
 
 	Contains:	Secure AppleTalk Data Stream Protocol Interfaces.
 
 	Version:	Technology:	AOCE Toolbox 1.02
 				Release:	Universal Interfaces 3.0d3 on Copland DR1
 
 	Copyright:	 1984-1996 by Apple Computer, Inc.  All rights reserved.
 
 	Bugs?:		If you find a problem with this file, send the file and version
 				information (from above) and the problem description to:
 
 					Internet:	apple.bugs@applelink.apple.com
 					AppleLink:	APPLE.BUGS
 
*/
#ifndef __ADSPSECURE__
#define __ADSPSECURE__

#ifndef __TYPES__
#include <Types.h>
#endif
#ifndef __ADSP__
#include <ADSP.h>
#endif
#ifndef __OCEAUTHDIR__
#include <OCEAuthDir.h>
#endif

#ifdef __cplusplus
extern "C" {
#endif

#if PRAGMA_IMPORT_SUPPORTED
#pragma import on
#endif

#if PRAGMA_ALIGN_SUPPORTED
#pragma options align=mac68k
#endif

#if FOR_SYSTEM7_ONLY
/*
 New ADSP control codes

 * open a secure connection 
*/

enum {
	sdspOpen					= 229
};

/*
For secure connections, the eom field of ioParams contains two single-bit flags
(instead of a zero/non-zero byte). They are an encrypt flag (see below), and an
eom flag.  All other bits in that field should be zero.

To write an encrypted message, you must set an encrypt bit in the eom field of
the ioParams of your write call. Note: this flag is only checked on the first
write of a message (the first write on a connection, or the first write following
a write with eom set.
*/

enum {
	dspEOMBit					= 0,							/* set if EOM at end of write */
	dspEncryptBit				= 1								/* set to encrypt message */
};


enum {
	dspEOMMask					= 1 << dspEOMBit,
	dspEncryptMask				= 1 << dspEncryptBit
};

/*
Define an ADSPSecure parameter block, as used for the secure Open call.

 * size of ADSPSecure workspace 
*/

enum {
	sdspWorkSize				= 2048
};

struct TRSecureParams {
	unsigned short 					localCID;					/* local connection id */
	unsigned short 					remoteCID;					/* remote connection id */
	AddrBlock 						remoteAddress;				/* address of remote end */
	AddrBlock 						filterAddress;				/* address filter */
	unsigned long 					sendSeq;					/* local send sequence number */
	unsigned short 					sendWindow;					/* send window size */
	unsigned long 					recvSeq;					/* receive sequence number */
	unsigned long 					attnSendSeq;				/* attention send sequence number */
	unsigned long 					attnRecvSeq;				/* attention receive sequence number */
	unsigned char 					ocMode;						/* open connection mode */
	unsigned char 					ocInterval;					/* open connection request retry interval */
	unsigned char 					ocMaximum;					/* open connection request retry maximum */

	Boolean 						secure;						/*  --> TRUE if session was authenticated */
	AuthKeyPtr 						sessionKey;					/* <--> encryption key for session */
	unsigned long 					credentialsSize;			/*  --> length of credentials */
	void *							credentials;				/*  --> pointer to credentials */
	void *							workspace;					/*  --> pointer to workspace for connection align on even boundary and length = sdspWorkSize */
	AuthIdentity 					recipient;					/*  --> identity of recipient (or initiator if active mode */
	UTCTime 						issueTime;					/*  --> when credentials were issued */
	UTCTime 						expiry;						/*  --> when credentials expiry */
	RecordIDPtr 					initiator;					/* <--  RecordID of initiator returned here. Must give appropriate Buffer to hold RecordID (Only for passive or accept mode) */
	Boolean 						hasIntermediary;			/* <--  will be set if credentials has an intermediary */
	Boolean 						filler1;
	RecordIDPtr 					intermediary;				/* <--  RecordID of intermediary returned here. (If intermediary is found in credentials Must give appropriate Buffer to hold RecordID (Only for passive or accept mode) */
};
typedef struct TRSecureParams TRSecureParams;

typedef struct SDSPParamBlock SDSPParamBlock;
typedef SDSPParamBlock *SDSPPBPtr;
/*
		This ProcPtr uses register based parameters on the 68k and cannot
		be written in or called from a high-level language without the help of
		mixed mode or assembly glue.

			typedef pascal void (*SDSPIOCompletionProcPtr)(SDSPPBPtr paramBlock);

*/

#if GENERATINGCFM
typedef UniversalProcPtr SDSPIOCompletionUPP;
#else
typedef Register68kProcPtr SDSPIOCompletionUPP;
#endif
struct SDSPParamBlock {
	QElem *							qLink;
	short 							qType;
	short 							ioTrap;
	Ptr 							ioCmdAddr;
	SDSPIOCompletionUPP 			ioCompletion;
	OSErr 							ioResult;
	StringPtr 						ioNamePtr;
	short 							ioVRefNum;
	short 							ioCRefNum;					/* adsp driver refNum */
	short 							csCode;						/* adsp driver control code */
	long 							qStatus;					/* adsp internal use */
	short 							ccbRefNum;
	union {
		TRinitParams 					initParams;				/* dspInit, dspCLInit */
		TRopenParams 					openParams;				/* dspOpen, dspCLListen, dspCLDeny */
		TRcloseParams 					closeParams;			/*dspClose, dspRemove*/
		TRioParams 						ioParams;				/*dspRead, dspWrite*/
		TRattnParams 					attnParams;				/*dspAttention*/
		TRstatusParams 					statusParams;			/*dspStatus*/
		TRoptionParams 					optionParams;			/*dspOptions*/
		TRnewcidParams 					newCIDParams;			/*dspNewCID*/
		TRSecureParams 					secureParams;			/* dspOpenSecure */
	} 								u;
};


#if GENERATINGCFM
#else
#endif

enum {
	uppSDSPIOCompletionProcInfo = kRegisterBased
		 | REGISTER_ROUTINE_PARAMETER(1, kRegisterA0, SIZE_CODE(sizeof(SDSPPBPtr)))
};

#if GENERATINGCFM
#define NewSDSPIOCompletionProc(userRoutine)		\
		(SDSPIOCompletionUPP) NewRoutineDescriptor((ProcPtr)(userRoutine), uppSDSPIOCompletionProcInfo, GetCurrentArchitecture())
#else
#define NewSDSPIOCompletionProc(userRoutine)		\
		((SDSPIOCompletionUPP) (userRoutine))
#endif

#if GENERATINGCFM
#define CallSDSPIOCompletionProc(userRoutine, paramBlock)		\
		CallUniversalProc((UniversalProcPtr)(userRoutine), uppSDSPIOCompletionProcInfo, (paramBlock))
#else
/* (*SDSPIOCompletionUPP) cannot be called from a high-level language without the Mixed Mode Manager */
#endif
#endif

#if PRAGMA_ALIGN_SUPPORTED
#pragma options align=reset
#endif

#if PRAGMA_IMPORT_SUPPORTED
#pragma import off
#endif

#ifdef __cplusplus
}
#endif

#endif /* __ADSPSECURE__ */

