/*
 	File:		Appearance.h
 
 	Contains:	Appearance Manager Interfaces.
 
 	Version:	Technology:	System 8
 				Release:	Universal Interfaces 3.0d3 on Copland DR1
 
 	Copyright:	 1984-1996 by Apple Computer, Inc.  All rights reserved.
 
 	Bugs?:		If you find a problem with this file, send the file and version
 				information (from above) and the problem description to:
 
 					Internet:	apple.bugs@applelink.apple.com
 					AppleLink:	APPLE.BUGS
 
*/
#ifndef __APPEARANCE__
#define __APPEARANCE__

#ifndef __QUICKDRAW__
#include <Quickdraw.h>
#endif
#ifndef __TYPES__
#include <Types.h>
#endif

#ifdef __cplusplus
extern "C" {
#endif

#if PRAGMA_IMPORT_SUPPORTED
#pragma import on
#endif

#if PRAGMA_ALIGN_SUPPORTED
#pragma options align=mac68k
#endif

#if FOR_SYSTEM8_COOPERATIVE
/* Appearance Manager Error Codes (will move to Errors.i) -4200 through -4249 */

enum {
	appearanceBadPatternIndexErr = -4201						/* pattern index invalid */
};

/*
 * System Pattern (PixPat) Indices for GetThemePixPat and SetThemePen
*/

enum {
	kThemeGrowIconBorderPattern	= 1,							/* Windows */
	kThemeRootMenuBackgroundPattern = 2,						/* Menus */
	kThemeSelectedRootMenuBackgroundPattern = 3,
	kThemeDisabledRootMenuBackgroundPattern = 4,
	kThemeMenuBackgroundPattern	= 5,
	kThemeSelectedMenuBackgroundPattern = 6,
	kThemeDisabledMenuBackgroundPattern = 7,
	kThemeActivePushButtonBackgroundPattern = 8,				/* Controls */
	kThemePressedPushButtonBackgroundPattern = 9,
	kThemeInactivePushButtonBackgroundPattern = 10,
	kThemeActiveOffIconButtonBackgroundPattern = 11,
	kThemeActiveOnIconButtonBackgroundPattern = 12,
	kThemePressedOffIconButtonBackgroundPattern = 13,
	kThemePressedOnIconButtonBackgroundPattern = 14,
	kThemeMixedIconButtonBackgroundPattern = 15,
	kThemeInactiveIconButtonBackgroundPattern = 16,
	kThemeActivePopupButtonBackgroundPattern = 17,
	kThemePressedPopupButtonBackgroundPattern = 18,
	kThemeInactivePopupButtonBackgroundPattern = 19,
	kThemeActiveDialogBackgroundPattern = 20,					/* Dialogs */
	kThemeInactiveDialogBackgroundPattern = 21,
	kThemeActiveAlertBackgroundPattern = 22,
	kThemeInactiveAlertBackgroundPattern = 23,
	kThemeActiveModelessDialogBackgroundPattern = 24,
	kThemeInactiveModelessDialogBackgroundPattern = 25,
	kThemeObjectFocusPattern	= 26,
	kThemeActiveWindowHeaderBackgroundPattern = 27,				/* Primitives */
	kThemeInactiveWindowHeaderBackgroundPattern = 28,
	kThemeFinderListViewSortColumnPattern = 29,					/* Finder */
	kThemeFinderListViewBackgroundPattern = 30,
	kThemeFinderListViewSeparatorLinePattern = 31,
	kThemeFinderWindowBackgroundPattern = 32,
	kThemeUtilityWindowBackgroundPattern = 33,					/* Miscellaneous */
	kThemeStatusBarBackgroundPattern = 34,
	kThemeInactiveStatusBarBackgroundPattern = 35,
	kThemeDragHilitePattern		= 36							/* Drag Mgr */
};

/*
 * System Text and other RGBColor Indices for GetThemeColor and SetThemeFore/BackColor.
*/

enum {
	kThemeActiveDocumentWindowTitleColor = 1,					/* Windows */
	kThemeInactiveDocumentWindowTitleColor = 2,
	kThemeActiveMovableModalWindowTitleColor = 3,
	kThemeInactiveMovableModalWindowTitleColor = 4,
	kThemeActiveFloatingWindowTitleColor = 5,
	kThemeInactiveFloatingWindowTitleColor = 6,
	kThemeActiveDrawerWindowTitleColor = 7,
	kThemeInactiveDrawerWindowTitleColor = 8,
	kThemeRootMenuTextColor		= 9,							/* Menus */
	kThemeSelectedRootMenuTextColor = 10,
	kThemeDisabledRootMenuTextColor = 11,
	kThemeMenuTextColor			= 12,
	kThemeSelectedMenuTextColor	= 13,
	kThemeDisabledMenuTextColor	= 14,
	kThemeActivePushButtonTextColor = 15,						/* Controls */
	kThemePressedPushButtonTextColor = 16,
	kThemeInactivePushButtonTextColor = 17,
	kThemeActivePopupLabelTextColor = 18,
	kThemeInactivePopupLabelTextColor = 19,
	kThemeActivePopupArrowColor	= 20,
	kThemePressedPopupArrowColor = 21,
	kThemeInactivePopupArrowColor = 22,
	kThemeActiveDialogTextColor	= 23,							/* Dialogs */
	kThemeInactiveDialogTextColor = 24,
	kThemeActiveAlertTextColor	= 25,
	kThemeInactiveAlertTextColor = 26,
	kThemeActiveModelessDialogTextColor = 27,
	kThemeInactiveModelessDialogTextColor = 28,
	kThemeActiveWindowHeaderTextColor = 29,						/* Primitives */
	kThemeInactiveWindowHeaderTextColor = 30,
	kThemeIconLabelTextColor	= 31,							/* Finder */
	kThemeIconLabelBackgroundColor = 32,
	kThemeFinderListViewTextColor = 33,
	kThemeAppleGuideCoachmarkColor = 34,						/* Miscellaneous */
	kThemeChasingArrowsColor	= 35,
	kThemeStatusBarTextColor	= 36,
	kThemeInactiveStatusBarTextColor = 37
};

/*
 *	System Appearance Information
*/
/*
 System Patterns
 *
 * WARNING: Patterns returned by GetThemePixPat are shared by the system and other
 * running applications.  These patterns are updated by the system automatically
 * whenever the theme changes.  They are system-owned and must not be disposed.
 * Never dispose a PixPatHandle obtained from GetThemePixPat or the system will crash.
*/
extern pascal OSStatus GetThemePixPat(SInt16 patternIndex, PixPatHandle *pixPat);

extern pascal OSStatus SetThemePen(SInt16 patternIndex);

/* System colors */
extern pascal OSStatus SetThemeForeColor(SInt16 foreColorIndex);

extern pascal OSStatus SetThemeBackColor(SInt16 backColorIndex);

extern pascal OSStatus GetThemeColor(SInt16 colorIndex, RGBColor *color);

/*
 *	Appearance Drawing Primitives
*/
extern pascal OSStatus DrawThemePrimaryGroup(const Rect *rect, Boolean isActive);

extern pascal OSStatus DrawThemeSecondaryGroup(const Rect *rect, Boolean isActive);

extern pascal OSStatus DrawThemeSeparator(const Rect *rect, Boolean isActive);

extern pascal OSStatus DrawThemeWindowHeader(const Rect *rect, Boolean isActive);

extern pascal OSStatus DrawThemePlacard(const Rect *rect, Boolean isActive);

extern pascal OSStatus DrawThemeDialogFrame(const Rect *rect, Boolean isActive);

extern pascal OSStatus DrawThemeTextBoxFrame(const Rect *textBoxRect, Boolean isActive);

extern pascal OSStatus DrawThemeTextBoxFocus(const Rect *textBoxRect, Boolean hasFocus);

extern pascal OSStatus DrawThemeListBoxFrame(const Rect *listBoxRect, Boolean isActive);

extern pascal OSStatus DrawThemeListBoxFocus(const Rect *listBoxRect, Boolean hasFocus);

extern pascal OSStatus DrawThemeGenericFocus(const Rect *focusRect, Boolean hasFocus);

#endif

#if PRAGMA_ALIGN_SUPPORTED
#pragma options align=reset
#endif

#if PRAGMA_IMPORT_SUPPORTED
#pragma import off
#endif

#ifdef __cplusplus
}
#endif

#endif /* __APPEARANCE__ */

