/*
 	File:		ColorPickerComponents.h
 
 	Contains:	Color Picker Component Interfaces.
 
 	Version:	Technology:	System 7.5
 				Release:	Universal Interfaces 3.0d3 on Copland DR1
 
 	Copyright:	 1984-1996 by Apple Computer, Inc.  All rights reserved.
 
 	Bugs?:		If you find a problem with this file, send the file and version
 				information (from above) and the problem description to:
 
 					Internet:	apple.bugs@applelink.apple.com
 					AppleLink:	APPLE.BUGS
 
*/
#ifndef __COLORPICKERCOMPONENTS__
#define __COLORPICKERCOMPONENTS__

#ifndef __COLORPICKER__
#include <ColorPicker.h>
#endif
#ifndef __COMPONENTS__
#include <Components.h>
#endif
#ifndef __MIXEDMODE__
#include <MixedMode.h>
#endif

#ifdef __cplusplus
extern "C" {
#endif

#if PRAGMA_IMPORT_SUPPORTED
#pragma import on
#endif

#if PRAGMA_ALIGN_SUPPORTED
#pragma options align=mac68k
#endif

#if FOR_SYSTEM7_AND_SYSTEM8_COOPERATIVE

enum {
	kPickerComponentType		= 'cpkr'
};


enum {
	kPickerInit					= 0,
	kPickerTestGraphicsWorld	= 1,
	kPickerGetDialog			= 2,
	kPickerGetItemList			= 3,
	kPickerGetColor				= 4,
	kPickerSetColor				= 5,
	kPickerEvent				= 6,
	kPickerEdit					= 7,
	kPickerSetVisibility		= 8,
	kPickerDisplay				= 9,
	kPickerItemHit				= 10,
	kPickerSetBaseItem			= 11,
	kPickerGetProfile			= 12,
	kPickerSetProfile			= 13,
	kPickerGetPrompt			= 14,
	kPickerSetPrompt			= 15,
	kPickerGetIconData			= 16,
	kPickerGetEditMenuState		= 17,
	kPickerSetOrigin			= 18,
	kPickerExtractHelpItem		= 19
};

typedef pascal ComponentResult (*PickerOpenProcPtr)(long storage, ComponentInstance self);
typedef pascal ComponentResult (*PickerCloseProcPtr)(long storage, ComponentInstance self);
typedef pascal ComponentResult (*PickerCanDoProcPtr)(long storage, short selector);
typedef pascal ComponentResult (*PickerVersionProcPtr)(long storage);
typedef pascal ComponentResult (*PickerRegisterProcPtr)(long storage);
typedef pascal ComponentResult (*PickerSetTargetProcPtr)(long storage, ComponentInstance topOfCallChain);

#if GENERATINGCFM
typedef UniversalProcPtr PickerOpenUPP;
typedef UniversalProcPtr PickerCloseUPP;
typedef UniversalProcPtr PickerCanDoUPP;
typedef UniversalProcPtr PickerVersionUPP;
typedef UniversalProcPtr PickerRegisterUPP;
typedef UniversalProcPtr PickerSetTargetUPP;
#else
typedef PickerOpenProcPtr PickerOpenUPP;
typedef PickerCloseProcPtr PickerCloseUPP;
typedef PickerCanDoProcPtr PickerCanDoUPP;
typedef PickerVersionProcPtr PickerVersionUPP;
typedef PickerRegisterProcPtr PickerRegisterUPP;
typedef PickerSetTargetProcPtr PickerSetTargetUPP;
#endif
extern pascal ComponentResult PickerInit(long storage, PickerInitData *data)
 FIVEWORDINLINE(0x2F3C, 0x0004, 0x0000, 0x7000, 0xA82A);

typedef pascal ComponentResult (*PickerInitProcPtr)(long storage, PickerInitData *data);
extern pascal ComponentResult PickerTestGraphicsWorld(long storage, PickerInitData *data)
 FIVEWORDINLINE(0x2F3C, 0x0004, 0x0001, 0x7000, 0xA82A);

typedef pascal ComponentResult (*PickerTestGraphicsWorldProcPtr)(long storage, PickerInitData *data);
extern pascal ComponentResult PickerGetDialog(long storage)
 FIVEWORDINLINE(0x2F3C, 0x0000, 0x0002, 0x7000, 0xA82A);

typedef pascal ComponentResult (*PickerGetDialogProcPtr)(long storage);
extern pascal ComponentResult PickerGetItemList(long storage)
 FIVEWORDINLINE(0x2F3C, 0x0000, 0x0003, 0x7000, 0xA82A);

typedef pascal ComponentResult (*PickerGetItemListProcPtr)(long storage);
extern pascal ComponentResult PickerGetColor(long storage, ColorType whichColor, PMColorPtr color)
 FIVEWORDINLINE(0x2F3C, 0x0006, 0x0004, 0x7000, 0xA82A);

typedef pascal ComponentResult (*PickerGetColorProcPtr)(long storage, ColorType whichColor, PMColorPtr color);
extern pascal ComponentResult PickerSetColor(long storage, ColorType whichColor, PMColorPtr color)
 FIVEWORDINLINE(0x2F3C, 0x0006, 0x0005, 0x7000, 0xA82A);

typedef pascal ComponentResult (*PickerSetColorProcPtr)(long storage, ColorType whichColor, PMColorPtr color);
extern pascal ComponentResult PickerEvent(long storage, EventData *data)
 FIVEWORDINLINE(0x2F3C, 0x0004, 0x0006, 0x7000, 0xA82A);

typedef pascal ComponentResult (*PickerEventProcPtr)(long storage, EventData *data);
extern pascal ComponentResult PickerEdit(long storage, EditData *data)
 FIVEWORDINLINE(0x2F3C, 0x0004, 0x0007, 0x7000, 0xA82A);

typedef pascal ComponentResult (*PickerEditProcPtr)(long storage, EditData *data);
extern pascal ComponentResult PickerSetVisibility(long storage, Boolean visible)
 FIVEWORDINLINE(0x2F3C, 0x0002, 0x0008, 0x7000, 0xA82A);

typedef pascal ComponentResult (*PickerSetVisibilityProcPtr)(long storage, Boolean visible);
extern pascal ComponentResult PickerDisplay(long storage)
 FIVEWORDINLINE(0x2F3C, 0x0000, 0x0009, 0x7000, 0xA82A);

typedef pascal ComponentResult (*PickerDisplayProcPtr)(long storage);
extern pascal ComponentResult PickerItemHit(long storage, ItemHitData *data)
 FIVEWORDINLINE(0x2F3C, 0x0004, 0x000A, 0x7000, 0xA82A);

typedef pascal ComponentResult (*PickerItemHitProcPtr)(long storage, ItemHitData *data);
extern pascal ComponentResult PickerSetBaseItem(long storage, short baseItem)
 FIVEWORDINLINE(0x2F3C, 0x0002, 0x000B, 0x7000, 0xA82A);

typedef pascal ComponentResult (*PickerSetBaseItemProcPtr)(long storage, short baseItem);
extern pascal ComponentResult PickerGetProfile(long storage)
 FIVEWORDINLINE(0x2F3C, 0x0000, 0x000C, 0x7000, 0xA82A);

typedef pascal ComponentResult (*PickerGetProfileProcPtr)(long storage);
extern pascal ComponentResult PickerSetProfile(long storage, CMProfileHandle profile)
 FIVEWORDINLINE(0x2F3C, 0x0004, 0x000D, 0x7000, 0xA82A);

typedef pascal ComponentResult (*PickerSetProfileProcPtr)(long storage, CMProfileHandle profile);
extern pascal ComponentResult PickerGetPrompt(long storage, Str255 prompt)
 FIVEWORDINLINE(0x2F3C, 0x0004, 0x000E, 0x7000, 0xA82A);

typedef pascal ComponentResult (*PickerGetPromptProcPtr)(long storage, Str255 prompt);
extern pascal ComponentResult PickerSetPrompt(long storage, ConstStr255Param prompt)
 FIVEWORDINLINE(0x2F3C, 0x0004, 0x000F, 0x7000, 0xA82A);

typedef pascal ComponentResult (*PickerSetPromptProcPtr)(long storage, ConstStr255Param prompt);
extern pascal ComponentResult PickerGetIconData(long storage, PickerIconData *data)
 FIVEWORDINLINE(0x2F3C, 0x0004, 0x0010, 0x7000, 0xA82A);

typedef pascal ComponentResult (*PickerGetIconDataProcPtr)(long storage, PickerIconData *data);
extern pascal ComponentResult PickerGetEditMenuState(long storage, PickerMenuState *mState)
 FIVEWORDINLINE(0x2F3C, 0x0004, 0x0011, 0x7000, 0xA82A);

typedef pascal ComponentResult (*PickerGetEditMenuStateProcPtr)(long storage, PickerMenuState *mState);
extern pascal ComponentResult PickerSetOrigin(long storage, Point where)
 FIVEWORDINLINE(0x2F3C, 0x0004, 0x0012, 0x7000, 0xA82A);

typedef pascal ComponentResult (*PickerSetOriginProcPtr)(long storage, Point where);

#if GENERATINGCFM
typedef UniversalProcPtr PickerInitUPP;
typedef UniversalProcPtr PickerTestGraphicsWorldUPP;
typedef UniversalProcPtr PickerGetDialogUPP;
typedef UniversalProcPtr PickerGetItemListUPP;
typedef UniversalProcPtr PickerGetColorUPP;
typedef UniversalProcPtr PickerSetColorUPP;
typedef UniversalProcPtr PickerEventUPP;
typedef UniversalProcPtr PickerEditUPP;
typedef UniversalProcPtr PickerSetVisibilityUPP;
typedef UniversalProcPtr PickerDisplayUPP;
typedef UniversalProcPtr PickerItemHitUPP;
typedef UniversalProcPtr PickerSetBaseItemUPP;
typedef UniversalProcPtr PickerGetProfileUPP;
typedef UniversalProcPtr PickerSetProfileUPP;
typedef UniversalProcPtr PickerGetPromptUPP;
typedef UniversalProcPtr PickerSetPromptUPP;
typedef UniversalProcPtr PickerGetIconDataUPP;
typedef UniversalProcPtr PickerGetEditMenuStateUPP;
typedef UniversalProcPtr PickerSetOriginUPP;
#else
typedef PickerInitProcPtr PickerInitUPP;
typedef PickerTestGraphicsWorldProcPtr PickerTestGraphicsWorldUPP;
typedef PickerGetDialogProcPtr PickerGetDialogUPP;
typedef PickerGetItemListProcPtr PickerGetItemListUPP;
typedef PickerGetColorProcPtr PickerGetColorUPP;
typedef PickerSetColorProcPtr PickerSetColorUPP;
typedef PickerEventProcPtr PickerEventUPP;
typedef PickerEditProcPtr PickerEditUPP;
typedef PickerSetVisibilityProcPtr PickerSetVisibilityUPP;
typedef PickerDisplayProcPtr PickerDisplayUPP;
typedef PickerItemHitProcPtr PickerItemHitUPP;
typedef PickerSetBaseItemProcPtr PickerSetBaseItemUPP;
typedef PickerGetProfileProcPtr PickerGetProfileUPP;
typedef PickerSetProfileProcPtr PickerSetProfileUPP;
typedef PickerGetPromptProcPtr PickerGetPromptUPP;
typedef PickerSetPromptProcPtr PickerSetPromptUPP;
typedef PickerGetIconDataProcPtr PickerGetIconDataUPP;
typedef PickerGetEditMenuStateProcPtr PickerGetEditMenuStateUPP;
typedef PickerSetOriginProcPtr PickerSetOriginUPP;
#endif

enum {
	uppPickerOpenProcInfo = kPascalStackBased
		 | RESULT_SIZE(SIZE_CODE(sizeof(ComponentResult)))
		 | STACK_ROUTINE_PARAMETER(1, SIZE_CODE(sizeof(long)))
		 | STACK_ROUTINE_PARAMETER(2, SIZE_CODE(sizeof(ComponentInstance))),
	uppPickerCloseProcInfo = kPascalStackBased
		 | RESULT_SIZE(SIZE_CODE(sizeof(ComponentResult)))
		 | STACK_ROUTINE_PARAMETER(1, SIZE_CODE(sizeof(long)))
		 | STACK_ROUTINE_PARAMETER(2, SIZE_CODE(sizeof(ComponentInstance))),
	uppPickerCanDoProcInfo = kPascalStackBased
		 | RESULT_SIZE(SIZE_CODE(sizeof(ComponentResult)))
		 | STACK_ROUTINE_PARAMETER(1, SIZE_CODE(sizeof(long)))
		 | STACK_ROUTINE_PARAMETER(2, SIZE_CODE(sizeof(short))),
	uppPickerVersionProcInfo = kPascalStackBased
		 | RESULT_SIZE(SIZE_CODE(sizeof(ComponentResult)))
		 | STACK_ROUTINE_PARAMETER(1, SIZE_CODE(sizeof(long))),
	uppPickerRegisterProcInfo = kPascalStackBased
		 | RESULT_SIZE(SIZE_CODE(sizeof(ComponentResult)))
		 | STACK_ROUTINE_PARAMETER(1, SIZE_CODE(sizeof(long))),
	uppPickerSetTargetProcInfo = kPascalStackBased
		 | RESULT_SIZE(SIZE_CODE(sizeof(ComponentResult)))
		 | STACK_ROUTINE_PARAMETER(1, SIZE_CODE(sizeof(long)))
		 | STACK_ROUTINE_PARAMETER(2, SIZE_CODE(sizeof(ComponentInstance))),
	uppPickerInitProcInfo = kPascalStackBased
		 | RESULT_SIZE(SIZE_CODE(sizeof(ComponentResult)))
		 | STACK_ROUTINE_PARAMETER(1, SIZE_CODE(sizeof(long)))
		 | STACK_ROUTINE_PARAMETER(2, SIZE_CODE(sizeof(PickerInitData *))),
	uppPickerTestGraphicsWorldProcInfo = kPascalStackBased
		 | RESULT_SIZE(SIZE_CODE(sizeof(ComponentResult)))
		 | STACK_ROUTINE_PARAMETER(1, SIZE_CODE(sizeof(long)))
		 | STACK_ROUTINE_PARAMETER(2, SIZE_CODE(sizeof(PickerInitData *))),
	uppPickerGetDialogProcInfo = kPascalStackBased
		 | RESULT_SIZE(SIZE_CODE(sizeof(ComponentResult)))
		 | STACK_ROUTINE_PARAMETER(1, SIZE_CODE(sizeof(long))),
	uppPickerGetItemListProcInfo = kPascalStackBased
		 | RESULT_SIZE(SIZE_CODE(sizeof(ComponentResult)))
		 | STACK_ROUTINE_PARAMETER(1, SIZE_CODE(sizeof(long))),
	uppPickerGetColorProcInfo = kPascalStackBased
		 | RESULT_SIZE(SIZE_CODE(sizeof(ComponentResult)))
		 | STACK_ROUTINE_PARAMETER(1, SIZE_CODE(sizeof(long)))
		 | STACK_ROUTINE_PARAMETER(2, SIZE_CODE(sizeof(ColorType)))
		 | STACK_ROUTINE_PARAMETER(3, SIZE_CODE(sizeof(PMColorPtr))),
	uppPickerSetColorProcInfo = kPascalStackBased
		 | RESULT_SIZE(SIZE_CODE(sizeof(ComponentResult)))
		 | STACK_ROUTINE_PARAMETER(1, SIZE_CODE(sizeof(long)))
		 | STACK_ROUTINE_PARAMETER(2, SIZE_CODE(sizeof(ColorType)))
		 | STACK_ROUTINE_PARAMETER(3, SIZE_CODE(sizeof(PMColorPtr))),
	uppPickerEventProcInfo = kPascalStackBased
		 | RESULT_SIZE(SIZE_CODE(sizeof(ComponentResult)))
		 | STACK_ROUTINE_PARAMETER(1, SIZE_CODE(sizeof(long)))
		 | STACK_ROUTINE_PARAMETER(2, SIZE_CODE(sizeof(EventData *))),
	uppPickerEditProcInfo = kPascalStackBased
		 | RESULT_SIZE(SIZE_CODE(sizeof(ComponentResult)))
		 | STACK_ROUTINE_PARAMETER(1, SIZE_CODE(sizeof(long)))
		 | STACK_ROUTINE_PARAMETER(2, SIZE_CODE(sizeof(EditData *))),
	uppPickerSetVisibilityProcInfo = kPascalStackBased
		 | RESULT_SIZE(SIZE_CODE(sizeof(ComponentResult)))
		 | STACK_ROUTINE_PARAMETER(1, SIZE_CODE(sizeof(long)))
		 | STACK_ROUTINE_PARAMETER(2, SIZE_CODE(sizeof(Boolean))),
	uppPickerDisplayProcInfo = kPascalStackBased
		 | RESULT_SIZE(SIZE_CODE(sizeof(ComponentResult)))
		 | STACK_ROUTINE_PARAMETER(1, SIZE_CODE(sizeof(long))),
	uppPickerItemHitProcInfo = kPascalStackBased
		 | RESULT_SIZE(SIZE_CODE(sizeof(ComponentResult)))
		 | STACK_ROUTINE_PARAMETER(1, SIZE_CODE(sizeof(long)))
		 | STACK_ROUTINE_PARAMETER(2, SIZE_CODE(sizeof(ItemHitData *))),
	uppPickerSetBaseItemProcInfo = kPascalStackBased
		 | RESULT_SIZE(SIZE_CODE(sizeof(ComponentResult)))
		 | STACK_ROUTINE_PARAMETER(1, SIZE_CODE(sizeof(long)))
		 | STACK_ROUTINE_PARAMETER(2, SIZE_CODE(sizeof(short))),
	uppPickerGetProfileProcInfo = kPascalStackBased
		 | RESULT_SIZE(SIZE_CODE(sizeof(ComponentResult)))
		 | STACK_ROUTINE_PARAMETER(1, SIZE_CODE(sizeof(long))),
	uppPickerSetProfileProcInfo = kPascalStackBased
		 | RESULT_SIZE(SIZE_CODE(sizeof(ComponentResult)))
		 | STACK_ROUTINE_PARAMETER(1, SIZE_CODE(sizeof(long)))
		 | STACK_ROUTINE_PARAMETER(2, SIZE_CODE(sizeof(CMProfileHandle))),
	uppPickerGetPromptProcInfo = kPascalStackBased
		 | RESULT_SIZE(SIZE_CODE(sizeof(ComponentResult)))
		 | STACK_ROUTINE_PARAMETER(1, SIZE_CODE(sizeof(long)))
		 | STACK_ROUTINE_PARAMETER(2, SIZE_CODE(sizeof(Str255*))),
	uppPickerSetPromptProcInfo = kPascalStackBased
		 | RESULT_SIZE(SIZE_CODE(sizeof(ComponentResult)))
		 | STACK_ROUTINE_PARAMETER(1, SIZE_CODE(sizeof(long)))
		 | STACK_ROUTINE_PARAMETER(2, SIZE_CODE(sizeof(ConstStr255Param*))),
	uppPickerGetIconDataProcInfo = kPascalStackBased
		 | RESULT_SIZE(SIZE_CODE(sizeof(ComponentResult)))
		 | STACK_ROUTINE_PARAMETER(1, SIZE_CODE(sizeof(long)))
		 | STACK_ROUTINE_PARAMETER(2, SIZE_CODE(sizeof(PickerIconData *))),
	uppPickerGetEditMenuStateProcInfo = kPascalStackBased
		 | RESULT_SIZE(SIZE_CODE(sizeof(ComponentResult)))
		 | STACK_ROUTINE_PARAMETER(1, SIZE_CODE(sizeof(long)))
		 | STACK_ROUTINE_PARAMETER(2, SIZE_CODE(sizeof(PickerMenuState *))),
	uppPickerSetOriginProcInfo = kPascalStackBased
		 | RESULT_SIZE(SIZE_CODE(sizeof(ComponentResult)))
		 | STACK_ROUTINE_PARAMETER(1, SIZE_CODE(sizeof(long)))
		 | STACK_ROUTINE_PARAMETER(2, SIZE_CODE(sizeof(Point)))
};

#if GENERATINGCFM
#define NewPickerOpenProc(userRoutine)		\
		(PickerOpenUPP) NewRoutineDescriptor((ProcPtr)(userRoutine), uppPickerOpenProcInfo, GetCurrentArchitecture())
#define NewPickerCloseProc(userRoutine)		\
		(PickerCloseUPP) NewRoutineDescriptor((ProcPtr)(userRoutine), uppPickerCloseProcInfo, GetCurrentArchitecture())
#define NewPickerCanDoProc(userRoutine)		\
		(PickerCanDoUPP) NewRoutineDescriptor((ProcPtr)(userRoutine), uppPickerCanDoProcInfo, GetCurrentArchitecture())
#define NewPickerVersionProc(userRoutine)		\
		(PickerVersionUPP) NewRoutineDescriptor((ProcPtr)(userRoutine), uppPickerVersionProcInfo, GetCurrentArchitecture())
#define NewPickerRegisterProc(userRoutine)		\
		(PickerRegisterUPP) NewRoutineDescriptor((ProcPtr)(userRoutine), uppPickerRegisterProcInfo, GetCurrentArchitecture())
#define NewPickerSetTargetProc(userRoutine)		\
		(PickerSetTargetUPP) NewRoutineDescriptor((ProcPtr)(userRoutine), uppPickerSetTargetProcInfo, GetCurrentArchitecture())
#define NewPickerInitProc(userRoutine)		\
		(PickerInitUPP) NewRoutineDescriptor((ProcPtr)(userRoutine), uppPickerInitProcInfo, GetCurrentArchitecture())
#define NewPickerTestGraphicsWorldProc(userRoutine)		\
		(PickerTestGraphicsWorldUPP) NewRoutineDescriptor((ProcPtr)(userRoutine), uppPickerTestGraphicsWorldProcInfo, GetCurrentArchitecture())
#define NewPickerGetDialogProc(userRoutine)		\
		(PickerGetDialogUPP) NewRoutineDescriptor((ProcPtr)(userRoutine), uppPickerGetDialogProcInfo, GetCurrentArchitecture())
#define NewPickerGetItemListProc(userRoutine)		\
		(PickerGetItemListUPP) NewRoutineDescriptor((ProcPtr)(userRoutine), uppPickerGetItemListProcInfo, GetCurrentArchitecture())
#define NewPickerGetColorProc(userRoutine)		\
		(PickerGetColorUPP) NewRoutineDescriptor((ProcPtr)(userRoutine), uppPickerGetColorProcInfo, GetCurrentArchitecture())
#define NewPickerSetColorProc(userRoutine)		\
		(PickerSetColorUPP) NewRoutineDescriptor((ProcPtr)(userRoutine), uppPickerSetColorProcInfo, GetCurrentArchitecture())
#define NewPickerEventProc(userRoutine)		\
		(PickerEventUPP) NewRoutineDescriptor((ProcPtr)(userRoutine), uppPickerEventProcInfo, GetCurrentArchitecture())
#define NewPickerEditProc(userRoutine)		\
		(PickerEditUPP) NewRoutineDescriptor((ProcPtr)(userRoutine), uppPickerEditProcInfo, GetCurrentArchitecture())
#define NewPickerSetVisibilityProc(userRoutine)		\
		(PickerSetVisibilityUPP) NewRoutineDescriptor((ProcPtr)(userRoutine), uppPickerSetVisibilityProcInfo, GetCurrentArchitecture())
#define NewPickerDisplayProc(userRoutine)		\
		(PickerDisplayUPP) NewRoutineDescriptor((ProcPtr)(userRoutine), uppPickerDisplayProcInfo, GetCurrentArchitecture())
#define NewPickerItemHitProc(userRoutine)		\
		(PickerItemHitUPP) NewRoutineDescriptor((ProcPtr)(userRoutine), uppPickerItemHitProcInfo, GetCurrentArchitecture())
#define NewPickerSetBaseItemProc(userRoutine)		\
		(PickerSetBaseItemUPP) NewRoutineDescriptor((ProcPtr)(userRoutine), uppPickerSetBaseItemProcInfo, GetCurrentArchitecture())
#define NewPickerGetProfileProc(userRoutine)		\
		(PickerGetProfileUPP) NewRoutineDescriptor((ProcPtr)(userRoutine), uppPickerGetProfileProcInfo, GetCurrentArchitecture())
#define NewPickerSetProfileProc(userRoutine)		\
		(PickerSetProfileUPP) NewRoutineDescriptor((ProcPtr)(userRoutine), uppPickerSetProfileProcInfo, GetCurrentArchitecture())
#define NewPickerGetPromptProc(userRoutine)		\
		(PickerGetPromptUPP) NewRoutineDescriptor((ProcPtr)(userRoutine), uppPickerGetPromptProcInfo, GetCurrentArchitecture())
#define NewPickerSetPromptProc(userRoutine)		\
		(PickerSetPromptUPP) NewRoutineDescriptor((ProcPtr)(userRoutine), uppPickerSetPromptProcInfo, GetCurrentArchitecture())
#define NewPickerGetIconDataProc(userRoutine)		\
		(PickerGetIconDataUPP) NewRoutineDescriptor((ProcPtr)(userRoutine), uppPickerGetIconDataProcInfo, GetCurrentArchitecture())
#define NewPickerGetEditMenuStateProc(userRoutine)		\
		(PickerGetEditMenuStateUPP) NewRoutineDescriptor((ProcPtr)(userRoutine), uppPickerGetEditMenuStateProcInfo, GetCurrentArchitecture())
#define NewPickerSetOriginProc(userRoutine)		\
		(PickerSetOriginUPP) NewRoutineDescriptor((ProcPtr)(userRoutine), uppPickerSetOriginProcInfo, GetCurrentArchitecture())
#else
#define NewPickerOpenProc(userRoutine)		\
		((PickerOpenUPP) (userRoutine))
#define NewPickerCloseProc(userRoutine)		\
		((PickerCloseUPP) (userRoutine))
#define NewPickerCanDoProc(userRoutine)		\
		((PickerCanDoUPP) (userRoutine))
#define NewPickerVersionProc(userRoutine)		\
		((PickerVersionUPP) (userRoutine))
#define NewPickerRegisterProc(userRoutine)		\
		((PickerRegisterUPP) (userRoutine))
#define NewPickerSetTargetProc(userRoutine)		\
		((PickerSetTargetUPP) (userRoutine))
#define NewPickerInitProc(userRoutine)		\
		((PickerInitUPP) (userRoutine))
#define NewPickerTestGraphicsWorldProc(userRoutine)		\
		((PickerTestGraphicsWorldUPP) (userRoutine))
#define NewPickerGetDialogProc(userRoutine)		\
		((PickerGetDialogUPP) (userRoutine))
#define NewPickerGetItemListProc(userRoutine)		\
		((PickerGetItemListUPP) (userRoutine))
#define NewPickerGetColorProc(userRoutine)		\
		((PickerGetColorUPP) (userRoutine))
#define NewPickerSetColorProc(userRoutine)		\
		((PickerSetColorUPP) (userRoutine))
#define NewPickerEventProc(userRoutine)		\
		((PickerEventUPP) (userRoutine))
#define NewPickerEditProc(userRoutine)		\
		((PickerEditUPP) (userRoutine))
#define NewPickerSetVisibilityProc(userRoutine)		\
		((PickerSetVisibilityUPP) (userRoutine))
#define NewPickerDisplayProc(userRoutine)		\
		((PickerDisplayUPP) (userRoutine))
#define NewPickerItemHitProc(userRoutine)		\
		((PickerItemHitUPP) (userRoutine))
#define NewPickerSetBaseItemProc(userRoutine)		\
		((PickerSetBaseItemUPP) (userRoutine))
#define NewPickerGetProfileProc(userRoutine)		\
		((PickerGetProfileUPP) (userRoutine))
#define NewPickerSetProfileProc(userRoutine)		\
		((PickerSetProfileUPP) (userRoutine))
#define NewPickerGetPromptProc(userRoutine)		\
		((PickerGetPromptUPP) (userRoutine))
#define NewPickerSetPromptProc(userRoutine)		\
		((PickerSetPromptUPP) (userRoutine))
#define NewPickerGetIconDataProc(userRoutine)		\
		((PickerGetIconDataUPP) (userRoutine))
#define NewPickerGetEditMenuStateProc(userRoutine)		\
		((PickerGetEditMenuStateUPP) (userRoutine))
#define NewPickerSetOriginProc(userRoutine)		\
		((PickerSetOriginUPP) (userRoutine))
#endif

#if GENERATINGCFM
#define CallPickerOpenProc(userRoutine, storage, self)		\
		CallUniversalProc((UniversalProcPtr)(userRoutine), uppPickerOpenProcInfo, (storage), (self))
#define CallPickerCloseProc(userRoutine, storage, self)		\
		CallUniversalProc((UniversalProcPtr)(userRoutine), uppPickerCloseProcInfo, (storage), (self))
#define CallPickerCanDoProc(userRoutine, storage, selector)		\
		CallUniversalProc((UniversalProcPtr)(userRoutine), uppPickerCanDoProcInfo, (storage), (selector))
#define CallPickerVersionProc(userRoutine, storage)		\
		CallUniversalProc((UniversalProcPtr)(userRoutine), uppPickerVersionProcInfo, (storage))
#define CallPickerRegisterProc(userRoutine, storage)		\
		CallUniversalProc((UniversalProcPtr)(userRoutine), uppPickerRegisterProcInfo, (storage))
#define CallPickerSetTargetProc(userRoutine, storage, topOfCallChain)		\
		CallUniversalProc((UniversalProcPtr)(userRoutine), uppPickerSetTargetProcInfo, (storage), (topOfCallChain))
#define CallPickerInitProc(userRoutine, storage, data)		\
		CallUniversalProc((UniversalProcPtr)(userRoutine), uppPickerInitProcInfo, (storage), (data))
#define CallPickerTestGraphicsWorldProc(userRoutine, storage, data)		\
		CallUniversalProc((UniversalProcPtr)(userRoutine), uppPickerTestGraphicsWorldProcInfo, (storage), (data))
#define CallPickerGetDialogProc(userRoutine, storage)		\
		CallUniversalProc((UniversalProcPtr)(userRoutine), uppPickerGetDialogProcInfo, (storage))
#define CallPickerGetItemListProc(userRoutine, storage)		\
		CallUniversalProc((UniversalProcPtr)(userRoutine), uppPickerGetItemListProcInfo, (storage))
#define CallPickerGetColorProc(userRoutine, storage, whichColor, color)		\
		CallUniversalProc((UniversalProcPtr)(userRoutine), uppPickerGetColorProcInfo, (storage), (whichColor), (color))
#define CallPickerSetColorProc(userRoutine, storage, whichColor, color)		\
		CallUniversalProc((UniversalProcPtr)(userRoutine), uppPickerSetColorProcInfo, (storage), (whichColor), (color))
#define CallPickerEventProc(userRoutine, storage, data)		\
		CallUniversalProc((UniversalProcPtr)(userRoutine), uppPickerEventProcInfo, (storage), (data))
#define CallPickerEditProc(userRoutine, storage, data)		\
		CallUniversalProc((UniversalProcPtr)(userRoutine), uppPickerEditProcInfo, (storage), (data))
#define CallPickerSetVisibilityProc(userRoutine, storage, visible)		\
		CallUniversalProc((UniversalProcPtr)(userRoutine), uppPickerSetVisibilityProcInfo, (storage), (visible))
#define CallPickerDisplayProc(userRoutine, storage)		\
		CallUniversalProc((UniversalProcPtr)(userRoutine), uppPickerDisplayProcInfo, (storage))
#define CallPickerItemHitProc(userRoutine, storage, data)		\
		CallUniversalProc((UniversalProcPtr)(userRoutine), uppPickerItemHitProcInfo, (storage), (data))
#define CallPickerSetBaseItemProc(userRoutine, storage, baseItem)		\
		CallUniversalProc((UniversalProcPtr)(userRoutine), uppPickerSetBaseItemProcInfo, (storage), (baseItem))
#define CallPickerGetProfileProc(userRoutine, storage)		\
		CallUniversalProc((UniversalProcPtr)(userRoutine), uppPickerGetProfileProcInfo, (storage))
#define CallPickerSetProfileProc(userRoutine, storage, profile)		\
		CallUniversalProc((UniversalProcPtr)(userRoutine), uppPickerSetProfileProcInfo, (storage), (profile))
#define CallPickerGetPromptProc(userRoutine, storage, prompt)		\
		CallUniversalProc((UniversalProcPtr)(userRoutine), uppPickerGetPromptProcInfo, (storage), (prompt))
#define CallPickerSetPromptProc(userRoutine, storage, prompt)		\
		CallUniversalProc((UniversalProcPtr)(userRoutine), uppPickerSetPromptProcInfo, (storage), (prompt))
#define CallPickerGetIconDataProc(userRoutine, storage, data)		\
		CallUniversalProc((UniversalProcPtr)(userRoutine), uppPickerGetIconDataProcInfo, (storage), (data))
#define CallPickerGetEditMenuStateProc(userRoutine, storage, mState)		\
		CallUniversalProc((UniversalProcPtr)(userRoutine), uppPickerGetEditMenuStateProcInfo, (storage), (mState))
#define CallPickerSetOriginProc(userRoutine, storage, where)		\
		CallUniversalProc((UniversalProcPtr)(userRoutine), uppPickerSetOriginProcInfo, (storage), (where))
#else
#define CallPickerOpenProc(userRoutine, storage, self)		\
		(*(userRoutine))((storage), (self))
#define CallPickerCloseProc(userRoutine, storage, self)		\
		(*(userRoutine))((storage), (self))
#define CallPickerCanDoProc(userRoutine, storage, selector)		\
		(*(userRoutine))((storage), (selector))
#define CallPickerVersionProc(userRoutine, storage)		\
		(*(userRoutine))((storage))
#define CallPickerRegisterProc(userRoutine, storage)		\
		(*(userRoutine))((storage))
#define CallPickerSetTargetProc(userRoutine, storage, topOfCallChain)		\
		(*(userRoutine))((storage), (topOfCallChain))
#define CallPickerInitProc(userRoutine, storage, data)		\
		(*(userRoutine))((storage), (data))
#define CallPickerTestGraphicsWorldProc(userRoutine, storage, data)		\
		(*(userRoutine))((storage), (data))
#define CallPickerGetDialogProc(userRoutine, storage)		\
		(*(userRoutine))((storage))
#define CallPickerGetItemListProc(userRoutine, storage)		\
		(*(userRoutine))((storage))
#define CallPickerGetColorProc(userRoutine, storage, whichColor, color)		\
		(*(userRoutine))((storage), (whichColor), (color))
#define CallPickerSetColorProc(userRoutine, storage, whichColor, color)		\
		(*(userRoutine))((storage), (whichColor), (color))
#define CallPickerEventProc(userRoutine, storage, data)		\
		(*(userRoutine))((storage), (data))
#define CallPickerEditProc(userRoutine, storage, data)		\
		(*(userRoutine))((storage), (data))
#define CallPickerSetVisibilityProc(userRoutine, storage, visible)		\
		(*(userRoutine))((storage), (visible))
#define CallPickerDisplayProc(userRoutine, storage)		\
		(*(userRoutine))((storage))
#define CallPickerItemHitProc(userRoutine, storage, data)		\
		(*(userRoutine))((storage), (data))
#define CallPickerSetBaseItemProc(userRoutine, storage, baseItem)		\
		(*(userRoutine))((storage), (baseItem))
#define CallPickerGetProfileProc(userRoutine, storage)		\
		(*(userRoutine))((storage))
#define CallPickerSetProfileProc(userRoutine, storage, profile)		\
		(*(userRoutine))((storage), (profile))
#define CallPickerGetPromptProc(userRoutine, storage, prompt)		\
		(*(userRoutine))((storage), (prompt))
#define CallPickerSetPromptProc(userRoutine, storage, prompt)		\
		(*(userRoutine))((storage), (prompt))
#define CallPickerGetIconDataProc(userRoutine, storage, data)		\
		(*(userRoutine))((storage), (data))
#define CallPickerGetEditMenuStateProc(userRoutine, storage, mState)		\
		(*(userRoutine))((storage), (mState))
#define CallPickerSetOriginProc(userRoutine, storage, where)		\
		(*(userRoutine))((storage), (where))
#endif
#endif
#if FOR_SYSTEM7_AND_SYSTEM8_DEPRECATED
extern pascal ComponentResult PickerExtractHelpItem(long storage, short itemNo, short whichMsg, HelpItemInfo *helpInfo)
 FIVEWORDINLINE(0x2F3C, 0x0004, 0x0013, 0x7000, 0xA82A);

typedef pascal ComponentResult (*PickerExtractHelpItemProcPtr)(long storage, short itemNo, short whichMsg, HelpItemInfo *helpInfo);

#if GENERATINGCFM
typedef UniversalProcPtr PickerExtractHelpItemUPP;
#else
typedef PickerExtractHelpItemProcPtr PickerExtractHelpItemUPP;
#endif

enum {
	uppPickerExtractHelpItemProcInfo = kPascalStackBased
		 | RESULT_SIZE(SIZE_CODE(sizeof(ComponentResult)))
		 | STACK_ROUTINE_PARAMETER(1, SIZE_CODE(sizeof(long)))
		 | STACK_ROUTINE_PARAMETER(2, SIZE_CODE(sizeof(short)))
		 | STACK_ROUTINE_PARAMETER(3, SIZE_CODE(sizeof(short)))
		 | STACK_ROUTINE_PARAMETER(4, SIZE_CODE(sizeof(HelpItemInfo *)))
};

#if GENERATINGCFM
#define NewPickerExtractHelpItemProc(userRoutine)		\
		(PickerExtractHelpItemUPP) NewRoutineDescriptor((ProcPtr)(userRoutine), uppPickerExtractHelpItemProcInfo, GetCurrentArchitecture())
#else
#define NewPickerExtractHelpItemProc(userRoutine)		\
		((PickerExtractHelpItemUPP) (userRoutine))
#endif

#if GENERATINGCFM
#define CallPickerExtractHelpItemProc(userRoutine, storage, itemNo, whichMsg, helpInfo)		\
		CallUniversalProc((UniversalProcPtr)(userRoutine), uppPickerExtractHelpItemProcInfo, (storage), (itemNo), (whichMsg), (helpInfo))
#else
#define CallPickerExtractHelpItemProc(userRoutine, storage, itemNo, whichMsg, helpInfo)		\
		(*(userRoutine))((storage), (itemNo), (whichMsg), (helpInfo))
#endif
#endif

#if PRAGMA_ALIGN_SUPPORTED
#pragma options align=reset
#endif

#if PRAGMA_IMPORT_SUPPORTED
#pragma import off
#endif

#ifdef __cplusplus
}
#endif

#endif /* __COLORPICKERCOMPONENTS__ */

