/*
 	File:		TextEngineTypes.h
 
 	Version:	Technology:	System 8
 				Release:	Universal Interfaces 3.0d3 on Copland DR1
 
 	Copyright:	 1984-1996 by Apple Computer, Inc.  All rights reserved.
 
 	Bugs?:		If you find a problem with this file, send the file and version
 				information (from above) and the problem description to:
 
 					Internet:	apple.bugs@applelink.apple.com
 					AppleLink:	APPLE.BUGS
 
*/
#ifndef __TEXTENGINETYPES__
#define __TEXTENGINETYPES__

#ifndef __CONDITIONALMACROS__
#include <ConditionalMacros.h>
#endif
#ifndef __TYPES__
#include <Types.h>
#endif

#ifdef __cplusplus
extern "C" {
#endif

#if PRAGMA_IMPORT_SUPPORTED
#pragma import on
#endif

#if PRAGMA_ALIGN_SUPPORTED
#pragma options align=mac68k
#endif

#if FOR_SYSTEM8_COOPERATIVE
#ifdef __cplusplus
	class TSystemTextEngine;
	class HIEditTextPanel;
#else
	#include <som.h>
	#ifndef TSystemTextEngine
		#define TSystemTextEngine SOMObject
	#endif
	#ifndef HIEditTextPanel
		#define HIEditTextPanel SOMObject
	#endif
#endif
typedef OSType TextEngineID;
typedef UInt32 CharacterOffset;
typedef OptionBits TextEngineOptions;
typedef OptionBits TextIterationtype;
typedef OSType TextSelectionType;
typedef OSType TextAttributeTag;
typedef OSType TextEngineFeature;
typedef UInt32 EditCommandID;
typedef TextEngineFeature TFeatureList[1];
typedef UInt16 TextAlignment;
typedef OSType TextFontFace;
typedef struct OpaqueTextEngineRef* TextEngineRef;
typedef struct OpaqueTextDataStructureRef* TextDataStructureRef;
typedef struct OpaqueTextAttributeIteratorRef* TextAttributeIteratorRef;

enum {
																/*TextEngineID*/
	kTextEditEngine				= 'tedt'
};


enum {
																/*TextEngineFeature*/
	kMultiStyleFeature			= 'mlst',
	kTSM1_0AwareFeature			= 'tsm1',
	kTSM2_0AwareFeature			= 'tsm2',
	kMaskingModeFeature			= 'pswd',
	kTextSizeIsUInt32Feature	= 'tx32',
	kCoordinateSizeIsUInt32Feature = 'co32',
	kEmbeddableGraphicsFeature	= 'emgr',
	kEmbeddableSoundsFeature	= 'emsn',
	kEmbeddableMoviesFeature	= 'emmo',
	kEmbeddable3DGraphicsFeature = 'em3D',
	kHasCommandInterfaceObjectFeature = 'cmin',
	kGXBasedFeature				= 'gxba',
	kMultiLingualFeature		= 'mlng',
	kR2LSupportFeature			= 'r2ls',
	kVerticalTextSupportFeature	= 'vert',
	kAnnotationSupportFeature	= 'anot',
	kAETextSuiteSupportFeature	= 'aetx',
	kOpenDocSupportFeature		= 'odoc'
};


enum {
																/*TextEngineOptions option bits number*/
	kMaskedTextBit				= 0,
	kReadOnlySelectableBit		= 1,
	kDontInstallEventHandlerBit	= 2,
	kDontUseOffscreenBit		= 3
};


enum {
																/*Text engine option bits masks*/
	kStandardOptions			= 0,
	kMaskedTextMask				= 1 << kMaskedTextBit,
	kReadOnlySelectableMask		= 1 << kReadOnlySelectableBit,
	kDontInstallEventHandlerMask = 1 << kDontInstallEventHandlerBit,
	kDontUseOffscreenMask		= 1 << kDontUseOffscreenBit
};


enum {
																/*TextAttributeTag attribute tags for styles*/
	kEncodingAttribute			= 'encd',
	kFontAttribute				= 'font',
	kLanguageRegionAttribute	= 'lnrg',
	kHorizontalRunDirectionAttribute = 'hdir',					/*read only (cannot set it, deduced from encoding or font ??)*/
	kVVerticalRunDirectionAttribute = 'vdir',
	kSizeAttribute				= 'size',
	kfaceAttribute				= 'face',						/*QD style byte*/
	kColorAttribute				= 'colr',						/* tags for face*/
	kPlainFaceAttribute			= 'plin',
	kBoldFaceAttribute			= 'bold',
	kItalicFaceAttribute		= 'ital',
	kStrikeThroughFaceAttribute	= 'stkt',
	kUnderlineFaceAttribute		= 'undl',
	kDoubleUnderlineFaceAttribute = 'dudl',
	kOutlinefaceAttribute		= 'outl',
	kShadowFaceAttribute		= 'shdw',
	kCondensedFaceAttribute		= 'cnds',
	kExtendedFaceAttribute		= 'extd',
	kSuperScriptFaceAttribute	= 'susc',
	kSubScriptFaceAttribute		= 'subs'
};


enum {
																/*TextIterationtype*/
	kIterateOnCharacters		= 0x0001,
	kIterateOnWords				= 0x0002,
	kIterateOnLines				= 0x0004,
	kIterateOnParagraph			= 0x0008
};


enum {
																/*Alignmnent*/
	kTextAlignedWithDirection	= 0x0000,
	kTextAlignedRight			= 0x0002,
	kTextAlignedLeft			= 0x0004,
	kTextAlignedCenter			= 0x0008
};


enum {
																/* EditCommandID*/
	kNoCommand					= 0,
	kTypingCmd					= 1,
	kCutCmd						= 2,
	kCopyCmd					= 3,
	kPasteCmd					= 4,
	kClearCmd					= 5,
	kDropCmd					= 6,
	kAttributeChangeCmd			= 7
};


enum {
	kSwitchFaceOption			= 0x0000,
	kAddFaceOption				= 0x0001
};


enum {
	kTextAttrDontCare			= 0
};


enum {
	kTextStartIndex				= 0L,
	kTextEndIndex				= 0xFFFFFFFF
};


enum {
	kTextUnbounded				= 0L,
	kUseViewBounds				= -1L
};

typedef OSStatus (*MouseDownInTextTrackProcPtr)(TSystemTextEngine *theTextInstance, SInt32 hScroll, SInt32 vScroll, void *userData);
typedef OSStatus (*MouseDownInTextPanelTrackProcPtr)(HIEditTextPanel *theTextPanel, SInt32 hScroll, SInt32 vScroll, void *userData);
#endif

#if PRAGMA_ALIGN_SUPPORTED
#pragma options align=reset
#endif

#if PRAGMA_IMPORT_SUPPORTED
#pragma import off
#endif

#ifdef __cplusplus
}
#endif

#endif /* __TEXTENGINETYPES__ */

