/*
 	File:		TextInputSystem.h
 
 	Contains:	The handling of text input user interface.
 
 	Version:	Technology:	System 8
 				Release:	Universal Interfaces 3.0d3 on Copland DR1
 
 	Copyright:	 1984-1996 by Apple Computer, Inc.  All rights reserved.
 
 	Bugs?:		If you find a problem with this file, send the file and version
 				information (from above) and the problem description to:
 
 					Internet:	apple.bugs@applelink.apple.com
 					AppleLink:	APPLE.BUGS
 
*/
#ifndef __TEXTINPUTSYSTEM__
#define __TEXTINPUTSYSTEM__

#ifndef __TYPES__
#include <Types.h>
#endif
#ifndef __TEXTCOMMON__
#include <TextCommon.h>
#endif
#ifndef __LOCALEOBJECTS__
#include <LocaleObjects.h>
#endif

#ifdef __cplusplus
extern "C" {
#endif

#if PRAGMA_IMPORT_SUPPORTED
#pragma import on
#endif

#if PRAGMA_ALIGN_SUPPORTED
#pragma options align=mac68k
#endif

#if FOR_SYSTEM8_COOPERATIVE
/*____________________________________________________________________________________*/
/*

Routine:	GetCurrentTextInputLocaleIdentifier
			gets the LocaleIdentifier of the currently selected text input object.
Input:		NONE.
Output:		langRegionCode: the currently selected object.
OSStatus:	(no error, ?)
NOTE:		System8 only.

*/
extern OSStatus GetCurrentTextInputLocaleIdentifier(LocaleIdentifier *langRegionCode);

/*____________________________________________________________________________________*/
/*

Routine:	GetCurrentTextInputRef
			gets the current text input object reference.
Input:		NONE.
Output:		textInputObject: the currently selected object.
OSStatus:	(no error, ?)
NOTE:		System8 only.
*/
extern OSStatus GetCurrentTextInputRef(LocaleObjectRef *textInputObject);

/*____________________________________________________________________________________*/
/*

Routine:	SetCurrentTextInputLocaleIdentifier
			sets the current text input object according to the passed-in LocaleIdentifier.
Input:		textInputObject: the object selected by the client.
Output:		NONE.
OSStatus:	(no error, invalide object)
NOTE:		if the object is not shown, it will be displayed in the menu if the system supports
			this language/region/... locale.

*/
extern OSStatus SetCurrentTextInputLocaleIdentifier(LocaleIdentifier langRegionCode);

/*____________________________________________________________________________________*/
/*

Routine:	SetCurrentTextInputRef
			sets the current text input object ref.
Input:		textInputObject: the object selected by the client.
Output:		NONE.
OSStatus:	(no error, invalide object)
NOTE:		if the object is not shown, it will be displayed in the menu if the system supports
			this language/region/... locale.
*/
extern OSStatus SetCurrentTextInputRef(LocaleObjectRef textInputObject);

/*
____________________________________________________________________________________
	routines for converting between a text input object ref and the new LocaleIdentifier
____________________________________________________________________________________
*/
/*

Routine:	GetLocaleIdentifierFromTextInputObjectRef
			returns the LocaleIdentifier textInputObject represents.
Input:		textInputObject:	the reference of text input object.
Output:		langRegionCode:		localeIdentifier that this objects is stamped with.
OSStatus:	(no error, ?)
NOTE:		System8 only.

*/
extern OSStatus GetLocaleIdentifierFromTextInputObjectRef(LocaleObjectRef textInputObject, LocaleIdentifier *langRegionCode);

/*____________________________________________________________________________________*/
/*

Routine:	GetTextInputObjectRefFromLocaleIdentifier
			gets the object ref last designated by the user as representing the lanaguag/region
			LocaleIdentifier (or simply returns the default one), otherwise it returns null.
Input:		langRegioncode:		value of LocaleIdentifier.
Output:		textInputObject:	best match returned object.
OSStatus:	(no error, ?)
NOTE:		System8 only.

*/
extern OSStatus GetTextInputObjectRefFromLocaleIdentifier(LocaleIdentifier langRegionCode, LocaleObjectRef *textInputObject);

#endif

#if PRAGMA_ALIGN_SUPPORTED
#pragma options align=reset
#endif

#if PRAGMA_IMPORT_SUPPORTED
#pragma import off
#endif

#ifdef __cplusplus
}
#endif

#endif /* __TEXTINPUTSYSTEM__ */

